@@ -2,6 +2,7 @@ import datetime
 import inspect
 
 import pandas as pd
+from pandas.api.types import is_datetime64_any_dtype
 from pandas.core.window import Rolling as pd_Rolling
 from numbers import Integral
 
@@ -77,7 +78,7 @@ def map_overlap(func, df, before, after, *args, **kwargs):
     dd.DataFrame.map_overlap
     """
     if isinstance(before, datetime.timedelta) or isinstance(after, datetime.timedelta):
-        if not df.index._meta_nonempty.is_all_dates:
+        if not is_datetime64_any_dtype(df.index._meta_nonempty.inferred_type):
             raise TypeError(
                 "Must have a `DatetimeIndex` when using string offset "
                 "for `before` and `after`"
@@ -253,7 +254,7 @@ def pandas_rolling_method(df, rolling_kwargs, name, *args, **kwargs):
     return getattr(rolling, name)(*args, **kwargs)
 
 
-class Rolling(object):
+class Rolling:
     """Provides rolling window calculations."""
 
     def __init__(
