@@ -1,5 +1,4 @@
 import os
-import sys
 import signal
 import threading
 from multiprocessing.pool import ThreadPool
@@ -8,6 +7,7 @@ from time import time, sleep
 import pytest
 
 import dask
+from dask.system import CPU_COUNT
 from dask.threaded import get
 from dask.utils_test import inc, add
 
@@ -109,6 +109,19 @@ def test_dont_spawn_too_many_threads():
     assert after <= before + 8
 
 
+def test_dont_spawn_too_many_threads_CPU_COUNT():
+    before = threading.active_count()
+
+    dsk = {("x", i): (lambda: i,) for i in range(10)}
+    dsk["x"] = (sum, list(dsk))
+    for i in range(20):
+        get(dsk, "x")
+
+    after = threading.active_count()
+
+    assert after <= before + CPU_COUNT * 2
+
+
 def test_thread_safety():
     def f(x):
         return 1
@@ -133,11 +146,7 @@ def test_thread_safety():
     assert L == [1] * 20
 
 
-@pytest.mark.xfail(
-    "xdist" in sys.modules,
-    reason="This test fails intermittently when using pytest-xdist (maybe)",
-    strict=False,
-)
+@pytest.mark.flaky(reruns=10, reruns_delay=5)
 def test_interrupt():
     # Windows implements `queue.get` using polling,
     # which means we can set an exception to interrupt the call to `get`.
